@@ -62,12 +62,11 @@ pod2usage( -message => "Incorrect number of arguments",
 #     3. or else, distribution folder
 my $home = $^O eq 'MSWin32' ? $ENV{'userprofile'} : $ENV{'HOME'};
 my $configDir = $ENV{'BEAMERREVEAL_CONFIG'}
-  // File::Spec->catfile( $home, '.config', 'BeamerReveal' );
-my $configFileName = File::Spec->catfile( $configDir, 'config.ini' );
-$configFileName =
-  File::Spec->catfile( File::ShareDir::dist_dir( 'BeamerReveal' ) ,
-		       'config.ini' ) if ( ! -r $configFileName );
-dieExit( 13, "Error: cannot find config file" )
+  // "$home/.config/BeamerReveal";
+my $configFileName = "$configDir/config.ini";
+$configFileName = File::ShareDir::dist_dir( 'BeamerReveal' ) . '/config.ini'
+  if ( ! -r $configFileName );
+dieExit( 13, "Error: cannot find config file $configFileName" )
   unless( -r $configFileName );
 my $config = Config::Tiny->read( $configFileName )
   or dieExit( 14, $Config::Tiny::errstr . "\nin file '$configFileName'\n" );
@@ -187,8 +186,8 @@ $oFile->close();
 # finally let's create an index.html link
 my $symlink_exists = eval { symlink("",""); 1 };
 if ( $symlink_exists ) {
-  say STDERR "  - Creating index.html symlink";
-  symlink( "$oFileName", "index.html" );
+  say STDERR "  - Creating index.html link";
+  link( "$oFileName", "index.html" );
 }
 
 ########################
@@ -216,7 +215,7 @@ beamer-reveal.pl - converts the .rvl file and the corresponding pdf file to a fu
 
 =head1 VERSION
 
-version 20251224.1500
+version 20251226.1345
 
 =head1 SYNOPSIS
 
